@@ -3,7 +3,7 @@
  *
  * MIT license
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -15,7 +15,7 @@
  *
  * Apache license, Version 2.0
  *
- * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ * Copyright (c) 2018-2022 Dariusz Depta Engos Software
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -72,7 +72,7 @@ pub fn evaluate_equals(left: &Value, right: &Value) -> bool {
   crate::builders::eval_ternary_equality(left, right).unwrap_or(false)
 }
 
-/// Evaluates a context.
+/// Evaluates a context from text containing `FEEL` expression.
 pub fn evaluate_context(scope: &Scope, input: &str) -> Result<FeelContext> {
   let node = &dmntk_feel_parser::parse_context(scope, input, false)?;
   let evaluator = crate::builders::build_evaluator(node)?;
@@ -82,3 +82,13 @@ pub fn evaluate_context(scope: &Scope, input: &str) -> Result<FeelContext> {
     Err(err_not_a_context())
   }
 }
+
+/// Evaluates a context from AST node.
+pub fn evaluate_context_node(scope: &Scope, node: &AstNode) -> Result<FeelContext> {
+  let evaluator = crate::builders::build_evaluator(node)?;
+  if let Value::Context(context) = evaluator(scope) {
+    Ok(context)
+  } else {
+    Err(err_not_a_context())
+  }
+}
